Connector Models
================

Normalized connector definitions used by config-driven ETL workflows.

.. autosummary::
   :toctree: generated

   etlplus.connector.api
   etlplus.connector.database
   etlplus.connector.enums
   etlplus.connector.file
   etlplus.connector.types
